@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: kan-extensions
 version: 5.0.1
-id: kan-extensions-5.0.1-76348eb8b9558b599268f83ff585a869
-key: kanex_KIpHhFdWsK8Eb9nTmdh49U
+id: kan-extensions-5.0.1-8b12ed7d1d7d420e05b673cf71306cea
+key: kanex_CsVOON1VfTA2iOZ2DxjZw3
 license: BSD3
 copyright: Copyright (C) 2008-2016 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -25,18 +25,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/kan-extensions-5.0.1
-hs-libraries: HSkan-extensions-5.0.1-KIpHhFdWsK8Eb9nTmdh49U
+hs-libraries: HSkan-extensions-5.0.1-CsVOON1VfTA2iOZ2DxjZw3
 depends:
-    adjunctions-4.3-51e7d4a24d361113244a76d085504c45
+    adjunctions-4.3-306c4088e5ded361b522da44159f8d3e
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-3b2e208311908bc5a9db1ceb26126917
+    comonad-5-eb230ef163a26fe6410daceeb92d736a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
+    contravariant-1.4-1bd57c2540cd2864a467c8bf62a3fdb4
     distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
-    free-4.12.4-f8dab736d0d811e91eb50084b5673f3a
+    free-4.12.4-5e68614777ed20792496ad931a527625
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    semigroupoids-5.0.1-ab1721c6c7a72801e6cd851407a313ad
+    semigroupoids-5.0.1-9020d584fd071e35efe756eb398e9c78
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
